==> 0.3.tar.gz: vuetube/NUXT/plugins/languages/english.js <==
module.exports = {
  name: "English",

  global: {
    home: "Home",
    subscriptions: "Subscriptions",
    library: "Library",
    restart: "Restart",
    later: "Later",
    settingRestart: "Modifying this setting requires the app to restart for the changes to be applied."
  },

  index: {
    connecting: "Connecting",
    plugins: "Loading Plugins",
    launching: "Launching",
  },

  settings: {
    general: "General",
    theme: "Theme",
    player: "Player",
    uitweaker: "UI Tweaker",
    startupoptions: "Startup Options",
    plugins: "Plugins",
    updates: "Updates",
    logs: "Logs",
    about: "About",
    devmode: "Registry Editor",
  },

  mods: {
    general: {
      language: "Language",
    },
    theme: {
      normal: "Normal",
      adaptive: "Adaptive",
      custom: "Custom",
      dark: "Dark",
      black: "Black",
      darkmode: "Dark Mode",
      darkmodetagline: "Bravo Six, Going Dark.",
    },
    tweaks: {
      fullscreen: "Fullscreen",
      navbarblur: "Navbar Blur",
      roundedcorners: "Rounded Corners",
      roundthumbnails: "Round Thumbnails",
      roundwatchpagecomponents: "Round Watch Page Components",
      radius: "Radius",
    },
    startup: {
      defaultpage: "Default Page",
    },
    updates: {
      install: "Install",
      view: "View",
      latest: "Latest",
      installed: "Installed",
    },
    logs: {
      more: "More",
    },
    about: {
      appinformation: "App Information",
      appversion: "App Version",
      deviceinformation: "Device Information",
      platform: "Platform",
      os: "Operating System",
      model: "Model",
      manufacturer: "Manufacturer",
      emulator: "Emulator",
      github: "GitHub",
      discord: "Discord",
    },
  },

  events: {
    welcome: "Welcome to VueTube",
    tagline: "The future of video streaming",
    next: "Next",
    updated: "VueTube Was Updated!",
    awesome: "Awesome!",
    langsetup: "Let's Pick a Language!",
    featuresetup: "Let's Pick Some Features!",
    enableryd: "Enable Return YouTube Dislike",
    enablespb: "Enable SponsorBlock",
    thanks: "Thanks for Using VueTube",
    enjoy: "We hope you have an amazing experience",
  },
};

==> 0.4.1.tar.gz: vuetube/NUXT/plugins/languages/english.js <==
module.exports = {
  name: "English",

  global: {
    home: "Home",
    subscriptions: "Subscriptions",
    library: "Library",
    restart: "Restart",
    later: "Later",
    settingRestart: "Modifying this setting requires the app to restart for the changes to be applied."
  },

  index: {
    connecting: "Connecting",
    plugins: "Loading Plugins",
    launching: "Launching",
  },

  settings: {
    general: "General",
    theme: "Theme",
    player: "Player",
    uitweaker: "UI Tweaker",
    startupoptions: "Startup Options",
    plugins: "Plugins",
    updates: "Updates",
    logs: "Logs",
    about: "About",
    devmode: "Registry Editor",
  },

  mods: {
    general: {
      language: "Language",
    },
    theme: {
      normal: "Normal",
      adaptive: "Adaptive",
      custom: "Custom",
      dark: "Dark",
      black: "Black",
      darkmode: "Dark Mode",
      darkmodetagline: "Bravo Six, Going Dark.",
    },
    tweaks: {
      fullscreen: "Fullscreen",
      navbarblur: "Navbar Blur",
      roundedcorners: "Rounded Corners",
      roundthumbnails: "Round Thumbnails",
      roundwatchpagecomponents: "Round Watch Page Components",
      radius: "Radius",
    },
    startup: {
      defaultpage: "Default Page",
    },
    updates: {
      checking: "Checking for updates",
      available: "Update available",
      noupdate: "No updates available",
      noupdatemessage: "You're using the most recent version of VueTube. Check back later for updates.",

      installed: "Installed Version",
      latest: "Latest Version",

      okay: "Okay",
      update: "Update",
      later: "Later",
    },
    logs: {
      more: "More",
    },
    about: {
      appinformation: "App Information",
      appversion: "App Version",
      deviceinformation: "Device Information",
      platform: "Platform",
      os: "Operating System",
      model: "Model",
      manufacturer: "Manufacturer",
      emulator: "Emulator",
      github: "GitHub",
      discord: "Discord",
    },
  },

  events: {
    welcome: "Welcome to VueTube",
    tagline: "The future of video streaming",
    next: "Next",
    updated: "VueTube Was Updated!",
    awesome: "Awesome!",
    langsetup: "Let's Pick a Language!",
    featuresetup: "Let's Pick Some Features!",
    enableryd: "Enable Return YouTube Dislike",
    enablespb: "Enable SponsorBlock",
    thanks: "Thanks for Using VueTube",
    enjoy: "We hope you have an amazing experience",
    packageinstaller: "Select a Package to Download"
  },
};
